# Table of Contents

- [meta-model-v3](<./meta-model-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Meta Model v3](<./Meta-Model-v3.md>)
  - [Overview](<./Meta-Model-v3/Overview.md>)
  - [SAP LeanIX Meta Model v3](<./Meta-Model-v3/SAP-LeanIX-Meta-Model-v3.md>)
  - [Optional Extensions of the Data Model](<./Meta-Model-v3/Optional-Extensions-of-the-Data-Model.md>)
  - [Modeling Guidelines for Meta Model v3](<./Meta-Model-v3/Modeling-Guidelines-for-Meta-Model-v3.md>)
